/**
  *  \file game/load-host.cc
  *
  *  (c) 2001-2006 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/load.h"
#include "util/console.h"
#include "util/nls.h"
#include "util/except.h"
#include "game/global.h"

void
loadHostDirectory(GGameTurn& trn, Directory& d)
{
    TInt16 n;

    console.write(LOG_INFO, _("Loading host data..."));

    /* Mark everyone as active */
    for (int i = 1; i <= NUM_PLAYERS; ++i)
        trn.setHaveData(i);

    /* Ships */
    Ptr<Stream> s = d.openFileT("ship.hst", Stream::C_READ);
    int num_ships = (s->getSize() - 2) / TShip::size;
    if (num_ships < 500)
        throw FileTooShortException(s->getName());
    if (num_ships > NUM_SHIPS)
        num_ships = NUM_SHIPS;
    getStructure(*s, n);
    loadShips(trn, *s, num_ships, LoadBoth, GPlayerSet());

    /* Planets */
    s = d.openFileT("pdata.hst", Stream::C_READ);
    getStructure(*s, n);
    loadPlanets(trn, *s, NUM_PLANETS, LoadBoth, GPlayerSet());

    /* Bases */
    s = d.openFileT("bdata.hst", Stream::C_READ);
    getStructure(*s, n);
    loadBases(trn, *s, NUM_PLANETS, LoadBoth, GPlayerSet());
}
